import { type ReadableBox } from "svelte-toolbelt";
import type { InteractOutsideBehaviorType } from "../utilities/dismissible-layer/types.js";
import type { ReadableBoxedValues, WritableBoxedValues } from "../../internal/box.svelte.js";
import { type UseRovingFocusReturn } from "../../internal/use-roving-focus.svelte.js";
import type { Direction } from "../../shared/index.js";
import type { BitsFocusEvent, BitsKeyboardEvent, BitsPointerEvent, WithRefProps } from "../../internal/types.js";
type MenubarRootStateProps = WithRefProps<ReadableBoxedValues<{
    dir: Direction;
    loop: boolean;
}> & WritableBoxedValues<{
    value: string;
}>>;
declare class MenubarRootState {
    id: MenubarRootStateProps["id"];
    ref: MenubarRootStateProps["ref"];
    value: MenubarRootStateProps["value"];
    dir: MenubarRootStateProps["dir"];
    loop: MenubarRootStateProps["loop"];
    rovingFocusGroup: UseRovingFocusReturn;
    currentTabStopId: import("svelte-toolbelt").WritableBox<string | null>;
    wasOpenedByKeyboard: boolean;
    triggerIds: string[];
    valueToContentId: Map<string, ReadableBox<string>>;
    constructor(props: MenubarRootStateProps);
    registerTrigger(id: string): void;
    deRegisterTrigger(id: string): void;
    getTriggers(): HTMLButtonElement[];
    onMenuOpen(id: string): void;
    onMenuClose(): void;
    onMenuToggle(id: string): void;
    props: {
        readonly id: string;
        readonly role: "menubar";
        readonly "data-menubar-root": "";
    };
}
type MenubarMenuStateProps = ReadableBoxedValues<{
    value: string;
}>;
declare class MenubarMenuState {
    root: MenubarRootState;
    value: MenubarMenuStateProps["value"];
    open: boolean;
    wasOpenedByKeyboard: boolean;
    triggerNode: HTMLElement | null;
    contentNode: HTMLElement | null;
    constructor(props: MenubarMenuStateProps, root: MenubarRootState);
    getTriggerNode(): HTMLElement | null;
}
type MenubarTriggerStateProps = WithRefProps<ReadableBoxedValues<{
    disabled: boolean;
}>>;
declare class MenubarTriggerState {
    #private;
    id: MenubarTriggerStateProps["id"];
    ref: MenubarTriggerStateProps["ref"];
    disabled: MenubarTriggerStateProps["disabled"];
    menu: MenubarMenuState;
    root: MenubarRootState;
    isFocused: boolean;
    constructor(props: MenubarTriggerStateProps, menu: MenubarMenuState);
    onpointerdown(e: BitsPointerEvent): void;
    onpointerenter(_: BitsPointerEvent): void;
    onkeydown(e: BitsKeyboardEvent): void;
    onfocus(_: BitsFocusEvent): void;
    onblur(_: BitsFocusEvent): void;
    props: {
        readonly type: "button";
        readonly role: "menuitem";
        readonly id: string;
        readonly "aria-haspopup": "menu";
        readonly "aria-expanded": "true" | "false";
        readonly "aria-controls": string | undefined;
        readonly "data-highlighted": "" | undefined;
        readonly "data-state": "open" | "closed";
        readonly "data-disabled": "" | undefined;
        readonly "data-menu-value": string;
        readonly disabled: true | undefined;
        readonly tabIndex: number;
        readonly "data-menubar-trigger": "";
        readonly onpointerdown: (e: BitsPointerEvent) => void;
        readonly onpointerenter: (_: BitsPointerEvent) => void;
        readonly onkeydown: (e: BitsKeyboardEvent) => void;
        readonly onfocus: (_: BitsFocusEvent) => void;
        readonly onblur: (_: BitsFocusEvent) => void;
    };
}
type MenubarContentStateProps = WithRefProps<ReadableBoxedValues<{
    interactOutsideBehavior: InteractOutsideBehaviorType;
}>>;
declare class MenubarContentState {
    id: MenubarContentStateProps["id"];
    ref: MenubarContentStateProps["ref"];
    menu: MenubarMenuState;
    root: MenubarRootState;
    hasInteractedOutside: boolean;
    interactOutsideBehavior: MenubarContentStateProps["interactOutsideBehavior"];
    constructor(props: MenubarContentStateProps, menu: MenubarMenuState);
    onCloseAutoFocus(e: Event): void;
    onFocusOutside(e: Event): void;
    onInteractOutside(): void;
    onOpenAutoFocus(): void;
    onkeydown(e: BitsKeyboardEvent): void;
    props: {
        readonly id: string;
        readonly "aria-labelledby": string | undefined;
        readonly style: {
            readonly "--bits-menubar-content-transform-origin": "var(--bits-floating-transform-origin)";
            readonly "--bits-menubar-content-available-width": "var(--bits-floating-available-width)";
            readonly "--bits-menubar-content-available-height": "var(--bits-floating-available-height)";
            readonly "--bits-menubar-anchor-width": "var(--bits-floating-anchor-width)";
            readonly "--bits-menubar-anchor-height": "var(--bits-floating-anchor-height)";
        };
        readonly onkeydown: (e: BitsKeyboardEvent) => void;
        readonly "data-menu-content": "";
    };
}
export declare function useMenubarRoot(props: MenubarRootStateProps): MenubarRootState;
export declare function useMenubarMenu(props: MenubarMenuStateProps): MenubarMenuState;
export declare function useMenubarTrigger(props: MenubarTriggerStateProps): MenubarTriggerState;
export declare function useMenubarContent(props: MenubarContentStateProps): MenubarContentState;
export {};
