import { useRefById } from "svelte-toolbelt";
import { getAriaPressed, getDataDisabled, getDisabled } from "../../internal/attrs.js";
const ROOT_ATTR = "data-toggle-root";
class ToggleRootState {
    #id;
    #ref;
    #disabled;
    pressed;
    constructor(props) {
        this.#disabled = props.disabled;
        this.pressed = props.pressed;
        this.#id = props.id;
        this.#ref = props.ref;
        useRefById({
            id: this.#id,
            ref: this.#ref,
        });
        this.onclick = this.onclick.bind(this);
    }
    #togglePressed() {
        if (!this.#disabled.current) {
            this.pressed.current = !this.pressed.current;
        }
    }
    onclick(_) {
        if (this.#disabled.current)
            return;
        this.#togglePressed();
    }
    props = $derived.by(() => ({
        [ROOT_ATTR]: "",
        id: this.#id.current,
        "data-disabled": getDataDisabled(this.#disabled.current),
        "aria-pressed": getAriaPressed(this.pressed.current),
        "data-state": getToggleDataState(this.pressed.current),
        disabled: getDisabled(this.#disabled.current),
        onclick: this.onclick,
    }));
}
export function useToggleRoot(props) {
    return new ToggleRootState(props);
}
export function getToggleDataState(condition) {
    return condition ? "on" : "off";
}
